from PyObjCTools.TestSupport import TestCase, min_os_level, max_os_level
import ColorSync


class TestColorSyncTransform(TestCase):
    @min_os_level("10.13")
    def testCFType(self):
        self.assertIsCFType(ColorSync.ColorSyncTransformRef)

    @min_os_level("10.13")
    def testFunctions(self):
        self.assertIsInstance(ColorSync.ColorSyncTransformGetTypeID(), int)

        self.assertResultIsCFRetained(ColorSync.ColorSyncTransformCreate)
        self.assertResultIsCFRetained(ColorSync.ColorSyncTransformCopyProperty)
        ColorSync.ColorSyncTransformSetProperty

        self.assertArgIsOut(ColorSync.ColorSyncTransformConvert, 3)
        self.assertArgIsVariableSize(ColorSync.ColorSyncTransformConvert, 3)
        self.assertArgIsIn(ColorSync.ColorSyncTransformConvert, 7)
        self.assertArgIsVariableSize(ColorSync.ColorSyncTransformConvert, 7)

    @min_os_level("10.13")
    def testConstants(self):
        self.assertEqual(ColorSync.kColorSync1BitGamut, 1)
        self.assertEqual(ColorSync.kColorSync8BitInteger, 2)
        self.assertEqual(ColorSync.kColorSync16BitInteger, 3)
        self.assertEqual(ColorSync.kColorSync16BitFloat, 4)
        self.assertEqual(ColorSync.kColorSync32BitInteger, 5)
        self.assertEqual(ColorSync.kColorSync32BitNamedColorIndex, 6)
        self.assertEqual(ColorSync.kColorSync32BitFloat, 7)
        self.assertEqual(ColorSync.kColorSync10BitInteger, 8)

        self.assertEqual(ColorSync.kColorSyncAlphaNone, 0)
        self.assertEqual(ColorSync.kColorSyncAlphaPremultipliedLast, 1)
        self.assertEqual(ColorSync.kColorSyncAlphaPremultipliedFirst, 2)
        self.assertEqual(ColorSync.kColorSyncAlphaLast, 3)
        self.assertEqual(ColorSync.kColorSyncAlphaFirst, 4)
        self.assertEqual(ColorSync.kColorSyncAlphaNoneSkipLast, 5)
        self.assertEqual(ColorSync.kColorSyncAlphaNoneSkipFirst, 6)

        self.assertEqual(ColorSync.kColorSyncAlphaInfoMask, 0x1F)
        self.assertEqual(ColorSync.kColorSyncByteOrderMask, 0x7000)
        self.assertEqual(ColorSync.kColorSyncByteOrderDefault, 0 << 12)
        self.assertEqual(ColorSync.kColorSyncByteOrder16Little, 1 << 12)
        self.assertEqual(ColorSync.kColorSyncByteOrder32Little, 2 << 12)
        self.assertEqual(ColorSync.kColorSyncByteOrder16Big, 3 << 12)
        self.assertEqual(ColorSync.kColorSyncByteOrder32Big, 4 << 12)

        self.assertIsInstance(ColorSync.kColorSyncProfile, str)
        self.assertIsInstance(ColorSync.kColorSyncRenderingIntent, str)
        self.assertIsInstance(ColorSync.kColorSyncRenderingIntentPerceptual, str)
        self.assertIsInstance(ColorSync.kColorSyncRenderingIntentRelative, str)
        self.assertIsInstance(ColorSync.kColorSyncRenderingIntentSaturation, str)
        self.assertIsInstance(ColorSync.kColorSyncRenderingIntentAbsolute, str)
        self.assertIsInstance(ColorSync.kColorSyncRenderingIntentUseProfileHeader, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformTag, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformDeviceToPCS, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformPCSToPCS, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformPCSToDevice, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformDeviceToDevice, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformGamutCheck, str)
        self.assertIsInstance(ColorSync.kColorSyncBlackPointCompensation, str)
        self.assertIsInstance(ColorSync.kColorSyncPreferredCMM, str)
        self.assertIsInstance(ColorSync.kColorSyncConvertQuality, str)
        self.assertIsInstance(ColorSync.kColorSyncBestQuality, str)
        self.assertIsInstance(ColorSync.kColorSyncNormalQuality, str)
        self.assertIsInstance(ColorSync.kColorSyncDraftQuality, str)
        self.assertIsInstance(ColorSync.kColorSyncConvertThreadCount, str)
        self.assertIsInstance(ColorSync.kColorSyncConvertUseVectorUnit, str)
        self.assertIsInstance(ColorSync.kColorSyncConvertUseExtendedRange, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformCreator, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformSrcSpace, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformDstSpace, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformCodeFragmentType, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformCodeFragmentMD5, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformFullConversionData, str)
        self.assertIsInstance(
            ColorSync.kColorSyncTransformSimplifiedConversionData, str
        )
        self.assertIsInstance(
            ColorSync.kColorSyncTransformParametricConversionData, str
        )
        self.assertIsInstance(ColorSync.kColorSyncConversionMatrix, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionParamCurve0, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionParamCurve1, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionParamCurve2, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionParamCurve3, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionParamCurve4, str)
        self.assertIsInstance(ColorSync.kColorSyncConversion1DLut, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionGridPoints, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionChannelID, str)
        self.assertIsInstance(ColorSync.kColorSyncConversion3DLut, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionNDLut, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionInpChan, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionOutChan, str)
        self.assertIsInstance(ColorSync.kColorSyncConversionBPC, str)
        self.assertIsInstance(ColorSync.kColorSyncFixedPointRange, str)

        self.assertIsInstance(ColorSync.kColorSyncTransformCreator, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformSrcSpace, str)
        self.assertIsInstance(ColorSync.kColorSyncTransformDstSpace, str)

    @min_os_level("10.13")
    @max_os_level("10.13")
    def testConstants10_13_only(self):
        self.assertIsInstance(ColorSync.kColorSyncTranformInfo, str)

    @min_os_level("10.14")
    def testConstants10_14(self):
        self.assertIsInstance(ColorSync.kColorSyncTransformInfo, str)

    @min_os_level("10.15")
    def testConstants10_16(self):
        # XXX: Header says available in 10.16
        self.assertIsInstance(ColorSync.kColorSyncExtendedRange, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc
import ColorSync


class TestColorSyncProfile(TestCase):
    @min_os_level("10.13")
    def testCFType(self):
        self.assertIsCFType(ColorSync.ColorSyncProfileRef)
        self.assertIsCFType(ColorSync.ColorSyncMutableProfileRef)

    @min_os_level("10.4")
    def testFunctions10_4(self):
        self.assertResultHasType(ColorSync.ColorSyncProfileIsWideGamut, objc._C_BOOL)

    @min_os_level("10.13")
    def testFunctions10_13(self):
        self.assertIsInstance(ColorSync.ColorSyncProfileGetTypeID(), int)

        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCreate)
        self.assertArgIsOut(ColorSync.ColorSyncProfileCreate, 1)

        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCreateWithURL)
        self.assertArgIsOut(ColorSync.ColorSyncProfileCreateWithURL, 1)

        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCreateWithName)
        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCreateWithName)
        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCreateDeviceProfile)
        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCreateMutable)
        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCreateMutableCopy)
        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCreateLink)

        self.assertArgIsOut(ColorSync.ColorSyncProfileVerify, 1)
        self.assertArgIsOut(ColorSync.ColorSyncProfileVerify, 2)

        self.assertArgIsOut(ColorSync.ColorSyncProfileEstimateGammaWithDisplayID, 1)
        self.assertArgIsOut(ColorSync.ColorSyncProfileEstimateGamma, 1)

        ColorSync.ColorSyncProfileGetMD5

        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCopyData)
        self.assertArgIsOut(ColorSync.ColorSyncProfileCopyData, 1)

        ColorSync.ColorSyncProfileGetURL

        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCopyHeader)

        ColorSync.ColorSyncProfileSetHeader

        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCopyDescriptionString)
        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCopyTagSignatures)

        ColorSync.ColorSyncProfileContainsTag

        self.assertResultIsCFRetained(ColorSync.ColorSyncProfileCopyTag)

        ColorSync.ColorSyncProfileSetTag
        ColorSync.ColorSyncProfileRemoveTag

        self.assertArgIsOut(
            ColorSync.ColorSyncProfileGetDisplayTransferFormulaFromVCGT, 1
        )
        self.assertArgIsOut(
            ColorSync.ColorSyncProfileGetDisplayTransferFormulaFromVCGT, 2
        )
        self.assertArgIsOut(
            ColorSync.ColorSyncProfileGetDisplayTransferFormulaFromVCGT, 3
        )
        self.assertArgIsOut(
            ColorSync.ColorSyncProfileGetDisplayTransferFormulaFromVCGT, 4
        )
        self.assertArgIsOut(
            ColorSync.ColorSyncProfileGetDisplayTransferFormulaFromVCGT, 5
        )
        self.assertArgIsOut(
            ColorSync.ColorSyncProfileGetDisplayTransferFormulaFromVCGT, 6
        )
        self.assertArgIsOut(
            ColorSync.ColorSyncProfileGetDisplayTransferFormulaFromVCGT, 7
        )
        self.assertArgIsOut(
            ColorSync.ColorSyncProfileGetDisplayTransferFormulaFromVCGT, 8
        )
        self.assertArgIsOut(
            ColorSync.ColorSyncProfileGetDisplayTransferFormulaFromVCGT, 9
        )

        self.assertArgIsIn(
            ColorSync.ColorSyncProfileCreateDisplayTransferTablesFromVCGT, 1
        )

        self.assertArgIsFunction(
            ColorSync.ColorSyncIterateInstalledProfiles,
            0,
            objc._C_BOOL + b"^{__CFDictionary=}^v",
            False,
        )
        self.assertArgIsInOut(ColorSync.ColorSyncIterateInstalledProfiles, 1)
        self.assertArgIsOut(ColorSync.ColorSyncIterateInstalledProfiles, 3)

        self.assertArgIsInOut(ColorSync.ColorSyncIterateInstalledProfilesWithOptions, 1)
        self.assertArgIsOut(ColorSync.ColorSyncIterateInstalledProfilesWithOptions, 4)

        self.assertArgIsOut(ColorSync.ColorSyncProfileInstall, 3)
        self.assertArgIsOut(ColorSync.ColorSyncProfileUninstall, 1)

        self.assertArgIsInOut(ColorSync.ColorSyncIterateInstalledProfiles, 1)
        self.assertArgIsOut(ColorSync.ColorSyncIterateInstalledProfiles, 3)

        self.assertArgIsInOut(ColorSync.ColorSyncIterateInstalledProfilesWithOptions, 1)
        self.assertArgIsOut(ColorSync.ColorSyncIterateInstalledProfilesWithOptions, 4)

    @min_os_level("10.16")
    def testFunctions10_16(self):
        self.assertResultHasType(ColorSync.ColorSyncProfileIsMatrixBased, objc._C_BOOL)

    @min_os_level("10.13")
    def testConstants(self):
        self.assertIsInstance(ColorSync.kColorSyncGenericGrayProfile, str)
        self.assertIsInstance(ColorSync.kColorSyncGenericGrayGamma22Profile, str)
        self.assertIsInstance(ColorSync.kColorSyncGenericRGBProfile, str)
        self.assertIsInstance(ColorSync.kColorSyncGenericCMYKProfile, str)
        self.assertIsInstance(ColorSync.kColorSyncDisplayP3Profile, str)
        self.assertIsInstance(ColorSync.kColorSyncSRGBProfile, str)
        self.assertIsInstance(ColorSync.kColorSyncAdobeRGB1998Profile, str)
        self.assertIsInstance(ColorSync.kColorSyncGenericLabProfile, str)
        self.assertIsInstance(ColorSync.kColorSyncGenericXYZProfile, str)
        self.assertIsInstance(ColorSync.kColorSyncACESCGLinearProfile, str)
        self.assertIsInstance(ColorSync.kColorSyncDCIP3Profile, str)
        self.assertIsInstance(ColorSync.kColorSyncITUR709Profile, str)
        self.assertIsInstance(ColorSync.kColorSyncITUR2020Profile, str)
        self.assertIsInstance(ColorSync.kColorSyncROMMRGBProfile, str)
        self.assertIsInstance(ColorSync.kColorSyncProfileHeader, str)
        self.assertIsInstance(ColorSync.kColorSyncProfileClass, str)
        self.assertIsInstance(ColorSync.kColorSyncProfileColorSpace, str)
        self.assertIsInstance(ColorSync.kColorSyncProfilePCS, str)
        self.assertIsInstance(ColorSync.kColorSyncProfileURL, str)
        self.assertIsInstance(ColorSync.kColorSyncProfileDescription, str)
        self.assertIsInstance(ColorSync.kColorSyncProfileMD5Digest, str)
        self.assertIsInstance(ColorSync.kColorSyncSigAToB0Tag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigAToB1Tag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigAToB2Tag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigBToA0Tag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigBToA1Tag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigBToA2Tag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigCmykData, str)
        self.assertIsInstance(ColorSync.kColorSyncSigGrayData, str)
        self.assertIsInstance(ColorSync.kColorSyncSigLabData, str)
        self.assertIsInstance(ColorSync.kColorSyncSigRgbData, str)
        self.assertIsInstance(ColorSync.kColorSyncSigXYZData, str)
        self.assertIsInstance(ColorSync.kColorSyncSigAbstractClass, str)
        self.assertIsInstance(ColorSync.kColorSyncSigBlueTRCTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigBlueColorantTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigMediaBlackPointTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigCopyrightTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigProfileDescriptionTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigDeviceModelDescTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigDeviceMfgDescTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigGreenTRCTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigGreenColorantTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigGamutTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigGrayTRCTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigLinkClass, str)
        self.assertIsInstance(ColorSync.kColorSyncSigDisplayClass, str)
        self.assertIsInstance(ColorSync.kColorSyncSigNamedColor2Tag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigNamedColorClass, str)
        self.assertIsInstance(ColorSync.kColorSyncSigPreview0Tag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigPreview1Tag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigPreview2Tag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigOutputClass, str)
        self.assertIsInstance(ColorSync.kColorSyncSigProfileSequenceDescTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigRedTRCTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigRedColorantTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigInputClass, str)
        self.assertIsInstance(ColorSync.kColorSyncSigColorSpaceClass, str)
        self.assertIsInstance(ColorSync.kColorSyncSigTechnologyTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigViewingConditionsTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigViewingCondDescTag, str)
        self.assertIsInstance(ColorSync.kColorSyncSigMediaWhitePointTag, str)
        self.assertIsInstance(ColorSync.kColorSyncProfileComputerDomain, str)
        self.assertIsInstance(ColorSync.kColorSyncProfileUserDomain, str)

        self.assertEqual(
            ColorSync.COLORSYNC_PROFILE_INSTALL_ENTITLEMENT,
            b"com.apple.developer.ColorSync.profile.install",
        )
        self.assertEqual(ColorSync.COLORSYNC_MD5_LENGTH, 16)

    @min_os_level("10.16")
    def testConstants10_16(self):
        self.assertIsInstance(ColorSync.kColorSyncProfileCacheSeed, str)
        self.assertIsInstance(ColorSync.kColorSyncWaitForCacheReply, str)
        self.assertIsInstance(ColorSync.kColorSyncWaitForCacheReply, str)

    def testStructs(self):
        v = ColorSync.ColorSyncMD5()
        self.assertTrue(hasattr(v, "digest"))



from PyObjCTools.TestSupport import TestCase
import objc
import ColorSync


class TestColorSyncDevice(TestCase):
    def testConstants(self):
        self.assertIsInstance(ColorSync.kColorSyncDeviceID, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceClass, str)
        self.assertIsInstance(ColorSync.kColorSyncCameraDeviceClass, str)
        self.assertIsInstance(ColorSync.kColorSyncDisplayDeviceClass, str)
        self.assertIsInstance(ColorSync.kColorSyncPrinterDeviceClass, str)
        self.assertIsInstance(ColorSync.kColorSyncScannerDeviceClass, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceProfileURL, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceDescription, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceDescriptions, str)
        self.assertIsInstance(ColorSync.kColorSyncFactoryProfiles, str)
        self.assertIsInstance(ColorSync.kColorSyncCustomProfiles, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceModeDescription, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceModeDescriptions, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceDefaultProfileID, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceHostScope, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceUserScope, str)
        self.assertIsInstance(ColorSync.kColorSyncProfileHostScope, str)
        self.assertIsInstance(ColorSync.kColorSyncProfileUserScope, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceProfileIsFactory, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceProfileIsDefault, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceProfileIsCurrent, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceProfileID, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceRegisteredNotification, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceUnregisteredNotification, str)
        self.assertIsInstance(ColorSync.kColorSyncDeviceProfilesNotification, str)
        self.assertIsInstance(
            ColorSync.kColorSyncDisplayDeviceProfilesNotification, str
        )
        self.assertIsInstance(
            ColorSync.kColorSyncProfileRepositoryChangeNotification, str
        )
        self.assertIsInstance(ColorSync.kColorSyncRegistrationUpdateWindowServer, str)

    def testFunctions(self):
        ColorSync.ColorSyncRegisterDevice
        ColorSync.ColorSyncUnregisterDevice
        ColorSync.ColorSyncDeviceSetCustomProfiles
        self.assertResultIsCFRetained(ColorSync.ColorSyncDeviceCopyDeviceInfo)
        self.assertArgIsFunction(
            ColorSync.ColorSyncIterateDeviceProfiles,
            0,
            objc._C_BOOL + b"^{__CFDictionary=}^v",
            False,
        )
        self.assertResultIsCFRetained(ColorSync.CGDisplayCreateUUIDFromDisplayID)

        ColorSync.CGDisplayGetDisplayIDFromUUID



# This file is generated by objective.metadata
#
# Last update: Tue Nov 17 08:46:40 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
misc.update(
    {
        "ColorSyncMD5": objc.createStructType(
            "ColorSyncMD5", b"{_ColorSyncMD5=[16C]}", ["digest"]
        )
    }
)
constants = """$kCMMApplyTransformProcName$kCMMCreateTransformPropertyProcName$kCMMInitializeLinkProfileProcName$kCMMInitializeTransformProcName$kColorSyncACESCGLinearProfile$kColorSyncAdobeRGB1998Profile$kColorSyncBestQuality$kColorSyncBlackPointCompensation$kColorSyncCameraDeviceClass$kColorSyncConversion1DLut$kColorSyncConversion3DLut$kColorSyncConversionBPC$kColorSyncConversionChannelID$kColorSyncConversionGridPoints$kColorSyncConversionInpChan$kColorSyncConversionMatrix$kColorSyncConversionNDLut$kColorSyncConversionOutChan$kColorSyncConversionParamCurve0$kColorSyncConversionParamCurve1$kColorSyncConversionParamCurve2$kColorSyncConversionParamCurve3$kColorSyncConversionParamCurve4$kColorSyncConvertQuality$kColorSyncConvertThreadCount$kColorSyncConvertUseExtendedRange$kColorSyncConvertUseVectorUnit$kColorSyncCustomProfiles$kColorSyncDCIP3Profile$kColorSyncDeviceClass$kColorSyncDeviceDefaultProfileID$kColorSyncDeviceDescription$kColorSyncDeviceDescriptions$kColorSyncDeviceHostScope$kColorSyncDeviceID$kColorSyncDeviceModeDescription$kColorSyncDeviceModeDescriptions$kColorSyncDeviceProfileID$kColorSyncDeviceProfileIsCurrent$kColorSyncDeviceProfileIsDefault$kColorSyncDeviceProfileIsFactory$kColorSyncDeviceProfileURL$kColorSyncDeviceProfilesNotification$kColorSyncDeviceRegisteredNotification$kColorSyncDeviceUnregisteredNotification$kColorSyncDeviceUserScope$kColorSyncDisplayDeviceClass$kColorSyncDisplayDeviceProfilesNotification$kColorSyncDisplayP3Profile$kColorSyncDraftQuality$kColorSyncExtendedRange$kColorSyncFactoryProfiles$kColorSyncFixedPointRange$kColorSyncGenericCMYKProfile$kColorSyncGenericGrayGamma22Profile$kColorSyncGenericGrayProfile$kColorSyncGenericLabProfile$kColorSyncGenericRGBProfile$kColorSyncGenericXYZProfile$kColorSyncITUR2020Profile$kColorSyncITUR709Profile$kColorSyncNormalQuality$kColorSyncPreferredCMM$kColorSyncPrinterDeviceClass$kColorSyncProfile$kColorSyncProfileCacheSeed$kColorSyncProfileClass$kColorSyncProfileColorSpace$kColorSyncProfileComputerDomain$kColorSyncProfileDescription$kColorSyncProfileHeader$kColorSyncProfileHostScope$kColorSyncProfileMD5Digest$kColorSyncProfilePCS$kColorSyncProfileRepositoryChangeNotification$kColorSyncProfileURL$kColorSyncProfileUserDomain$kColorSyncProfileUserScope$kColorSyncROMMRGBProfile$kColorSyncRegistrationUpdateWindowServer$kColorSyncRenderingIntent$kColorSyncRenderingIntentAbsolute$kColorSyncRenderingIntentPerceptual$kColorSyncRenderingIntentRelative$kColorSyncRenderingIntentSaturation$kColorSyncRenderingIntentUseProfileHeader$kColorSyncSRGBProfile$kColorSyncScannerDeviceClass$kColorSyncSigAToB0Tag$kColorSyncSigAToB1Tag$kColorSyncSigAToB2Tag$kColorSyncSigAbstractClass$kColorSyncSigBToA0Tag$kColorSyncSigBToA1Tag$kColorSyncSigBToA2Tag$kColorSyncSigBlueColorantTag$kColorSyncSigBlueTRCTag$kColorSyncSigCmykData$kColorSyncSigColorSpaceClass$kColorSyncSigCopyrightTag$kColorSyncSigDeviceMfgDescTag$kColorSyncSigDeviceModelDescTag$kColorSyncSigDisplayClass$kColorSyncSigGamutTag$kColorSyncSigGrayData$kColorSyncSigGrayTRCTag$kColorSyncSigGreenColorantTag$kColorSyncSigGreenTRCTag$kColorSyncSigInputClass$kColorSyncSigLabData$kColorSyncSigLinkClass$kColorSyncSigMediaBlackPointTag$kColorSyncSigMediaWhitePointTag$kColorSyncSigNamedColor2Tag$kColorSyncSigNamedColorClass$kColorSyncSigOutputClass$kColorSyncSigPreview0Tag$kColorSyncSigPreview1Tag$kColorSyncSigPreview2Tag$kColorSyncSigProfileDescriptionTag$kColorSyncSigProfileSequenceDescTag$kColorSyncSigRedColorantTag$kColorSyncSigRedTRCTag$kColorSyncSigRgbData$kColorSyncSigTechnologyTag$kColorSyncSigViewingCondDescTag$kColorSyncSigViewingConditionsTag$kColorSyncSigXYZData$kColorSyncTranformInfo$kColorSyncTransformCodeFragmentMD5$kColorSyncTransformCodeFragmentType$kColorSyncTransformCreator$kColorSyncTransformDeviceToDevice$kColorSyncTransformDeviceToPCS$kColorSyncTransformDstSpace$kColorSyncTransformFullConversionData$kColorSyncTransformGamutCheck$kColorSyncTransformInfo$kColorSyncTransformPCSToDevice$kColorSyncTransformPCSToPCS$kColorSyncTransformParametricConversionData$kColorSyncTransformSimplifiedConversionData$kColorSyncTransformSrcSpace$kColorSyncTransformTag$kColorSyncWaitForCacheReply$"""
enums = """$COLORSYNC_MD5_LENGTH@16$kColorSync10BitInteger@8$kColorSync16BitFloat@4$kColorSync16BitInteger@3$kColorSync1BitGamut@1$kColorSync32BitFloat@7$kColorSync32BitInteger@5$kColorSync32BitNamedColorIndex@6$kColorSync8BitInteger@2$kColorSyncAlphaFirst@4$kColorSyncAlphaInfoMask@31$kColorSyncAlphaLast@3$kColorSyncAlphaNone@0$kColorSyncAlphaNoneSkipFirst@6$kColorSyncAlphaNoneSkipLast@5$kColorSyncAlphaPremultipliedFirst@2$kColorSyncAlphaPremultipliedLast@1$kColorSyncByteOrder16Big@12288$kColorSyncByteOrder16Little@4096$kColorSyncByteOrder32Big@16384$kColorSyncByteOrder32Little@8192$kColorSyncByteOrderDefault@0$kColorSyncByteOrderMask@28672$"""
misc.update(
    {
        "COLORSYNC_PROFILE_INSTALL_ENTITLEMENT": b"com.apple.developer.ColorSync.profile.install"
    }
)
functions = {
    "ColorSyncProfileCopyDescriptionString": (
        b"^{__CFString=}^{ColorSyncProfile=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncCMMCopyLocalizedName": (
        b"^{__CFString=}^{ColorSyncCMM=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncProfileCreateLink": (
        b"^{ColorSyncProfile=}^{__CFArray=}^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncCreateCodeFragment": (
        b"@^{__CFArray=}^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncProfileCreateDisplayTransferTablesFromVCGT": (
        b"^{__CFData=}^{ColorSyncProfile=}^Q",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"type_modifier": "n"}},
        },
    ),
    "CGDisplayGetDisplayIDFromUUID": (b"I^{__CFUUID=}",),
    "ColorSyncProfileCreateDeviceProfile": (
        b"^{ColorSyncProfile=}^{__CFString=}^{__CFUUID=}@",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncProfileCopyHeader": (
        b"^{__CFData=}^{ColorSyncProfile=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncProfileCopyTagSignatures": (
        b"^{__CFArray=}^{ColorSyncProfile=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncCMMGetTypeID": (b"Q",),
    "ColorSyncProfileCreateWithURL": (
        b"^{ColorSyncProfile=}^{__CFURL=}^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            },
        },
    ),
    "ColorSyncProfileVerify": (
        b"B^{ColorSyncProfile=}^^{__CFError=}^^{__CFError=}",
        "",
        {
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                },
                2: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                },
            }
        },
    ),
    "ColorSyncProfileIsMatrixBased": (b"B^{ColorSyncProfile=}",),
    "ColorSyncTransformConvert": (
        b"B^{ColorSyncTransform=}QQ^vIIQ^vIIQ^{__CFDictionary=}",
        "",
        {
            "arguments": {
                3: {"c_array_of_variable_length": True, "type_modifier": "o"},
                7: {"c_array_of_variable_length": True, "type_modifier": "n"},
            }
        },
    ),
    "ColorSyncCMMCreate": (
        b"^{ColorSyncCMM=}^{__CFBundle=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncProfileCreateWithDisplayID": (
        b"^{ColorSyncProfile=}I",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncProfileCreateMutableCopy": (
        b"^{ColorSyncProfile=}^{ColorSyncProfile=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "CGDisplayCreateUUIDFromDisplayID": (
        b"^{__CFUUID=}I",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncProfileInstall": (
        b"B^{ColorSyncProfile=}^{__CFString=}^{__CFString=}^^{__CFError=}",
        "",
        {
            "arguments": {
                3: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "ColorSyncProfileSetTag": (b"v^{ColorSyncProfile=}^{__CFString=}^{__CFData=}",),
    "ColorSyncTransformCreate": (
        b"^{ColorSyncTransform=}^{__CFArray=}^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncProfileCopyTag": (
        b"^{__CFData=}^{ColorSyncProfile=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncIterateDeviceProfiles": (
        b"v^?^v",
        "",
        {
            "arguments": {
                0: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": b"^{__CFDictionary=}"},
                            1: {"type": b"^v"},
                        },
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "ColorSyncProfileGetURL": (
        b"^{__CFURL=}^{ColorSyncProfile=}^^{__CFError=}",
        "",
        {
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "ColorSyncTransformSetProperty": (b"v^{ColorSyncTransform=}@@",),
    "ColorSyncUnregisterDevice": (b"B^{__CFString=}^{__CFUUID=}",),
    "ColorSyncDeviceCopyDeviceInfo": (
        b"^{__CFDictionary=}^{__CFString=}^{__CFUUID=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncProfileCreateMutable": (
        b"^{ColorSyncProfile=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncIterateInstalledProfiles": (
        b"v^?^I^v^^{__CFError=}",
        "",
        {
            "arguments": {
                0: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": b"^{__CFDictionary=}"},
                            1: {"type": b"^v"},
                        },
                    },
                    "callable_retained": False,
                },
                1: {"type_modifier": "N"},
                3: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                },
            }
        },
    ),
    "ColorSyncProfileUninstall": (
        b"B^{ColorSyncProfile=}^^{__CFError=}",
        "",
        {
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "ColorSyncProfileCopyData": (
        b"^{__CFData=}^{ColorSyncProfile=}^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            },
        },
    ),
    "ColorSyncIterateInstalledCMMs": (
        b"v^?^v",
        "",
        {
            "arguments": {
                0: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": b"^{ColorSyncCMM=}"},
                            1: {"type": b"^v"},
                        },
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "ColorSyncDeviceSetCustomProfiles": (
        b"B^{__CFString=}^{__CFUUID=}^{__CFDictionary=}",
    ),
    "ColorSyncCMMGetBundle": (b"^{__CFBundle=}^{ColorSyncCMM=}",),
    "ColorSyncIterateInstalledProfilesWithOptions": (
        b"v^?^I^v^{__CFDictionary=}^^{__CFError=}",
        "",
        {
            "arguments": {
                0: {
                    "callable": {
                        "retval": {"type": b"B"},
                        "arguments": {
                            0: {"type": b"^{__CFDictionary=}"},
                            1: {"type": b"^v"},
                        },
                    }
                },
                1: {"type_modifier": "N"},
                4: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                },
            }
        },
    ),
    "ColorSyncProfileGetTypeID": (b"Q",),
    "ColorSyncProfileCreateWithName": (
        b"^{ColorSyncProfile=}^{__CFString=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncTransformGetTypeID": (b"Q",),
    "ColorSyncProfileGetDisplayTransferFormulaFromVCGT": (
        b"B^{ColorSyncProfile=}^f^f^f^f^f^f^f^f^f",
        "",
        {
            "arguments": {
                1: {"type_modifier": "o"},
                2: {"type_modifier": "o"},
                3: {"type_modifier": "o"},
                4: {"type_modifier": "o"},
                5: {"type_modifier": "o"},
                6: {"type_modifier": "o"},
                7: {"type_modifier": "o"},
                8: {"type_modifier": "o"},
                9: {"type_modifier": "o"},
            }
        },
    ),
    "ColorSyncProfileIsWideGamut": (b"B^{ColorSyncProfile=}",),
    "ColorSyncRegisterDevice": (b"B^{__CFString=}^{__CFUUID=}^{__CFDictionary=}",),
    "ColorSyncProfileEstimateGammaWithDisplayID": (
        b"fi^^{__CFError=}",
        "",
        {
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "ColorSyncProfileGetMD5": (b"{_ColorSyncMD5=[16C]}^{ColorSyncProfile=}",),
    "ColorSyncProfileRemoveTag": (b"v^{ColorSyncProfile=}^{__CFString=}",),
    "ColorSyncProfileContainsTag": (b"B^{ColorSyncProfile=}^{__CFString=}",),
    "ColorSyncProfileEstimateGamma": (
        b"f^{ColorSyncProfile=}^^{__CFError=}",
        "",
        {
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            }
        },
    ),
    "ColorSyncProfileCreate": (
        b"^{ColorSyncProfile=}^{__CFData=}^^{__CFError=}",
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                1: {
                    "already_cfretained": True,
                    "type_modifier": "o",
                    "null_accepted": True,
                }
            },
        },
    ),
    "ColorSyncProfileSetHeader": (b"v^{ColorSyncProfile=}^{__CFData=}",),
    "ColorSyncTransformCopyProperty": (
        b"@^{ColorSyncTransform=}@^{__CFDictionary=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
    "ColorSyncCMMCopyCMMIdentifier": (
        b"^{__CFString=}^{ColorSyncCMM=}",
        "",
        {"retval": {"already_cfretained": True}},
    ),
}
aliases = {
    "CSEXTERN_DESKTOP": "CSEXTERN",
    "ColorSyncMutableProfileRef": "ColorSyncProfileRef",
    "CS_UNAVAILABLE_PUBLIC_EMBEDDED": "CS_UNAVAILABLE_EMBEDDED",
}
cftypes = [
    ("ColorSyncCMMRef", b"^{ColorSyncCMM=}", "ColorSyncCMMGetTypeID", None),
    ("ColorSyncProfileRef", b"^{ColorSyncProfile=}", "ColorSyncProfileGetTypeID", None),
    (
        "ColorSyncTransformRef",
        b"^{ColorSyncTransform=}",
        "ColorSyncTransformGetTypeID",
        None,
    ),
]
expressions = {}

# END OF FILE



from PyObjCTools.TestSupport import TestCase, min_os_level
import objc
import ColorSync


class TestColorSyncCMM(TestCase):
    @min_os_level("10.13")
    def testCFType(self):
        self.assertIsCFType(ColorSync.ColorSyncCMMRef)

    @min_os_level("10.13")
    def testFunctions(self):
        self.assertIsInstance(ColorSync.ColorSyncCMMGetTypeID(), int)
        self.assertResultIsCFRetained(ColorSync.ColorSyncCMMCreate)
        ColorSync.ColorSyncCMMGetBundle
        self.assertResultIsCFRetained(ColorSync.ColorSyncCMMCopyLocalizedName)
        self.assertResultIsCFRetained(ColorSync.ColorSyncCMMCopyCMMIdentifier)

        self.assertArgIsFunction(
            ColorSync.ColorSyncIterateInstalledCMMs,
            0,
            objc._C_BOOL + b"^{ColorSyncCMM=}^v",
            False,
        )

    @min_os_level("10.13")
    def testConstants(self):
        self.assertIsInstance(ColorSync.kCMMInitializeLinkProfileProcName, str)
        self.assertIsInstance(ColorSync.kCMMInitializeTransformProcName, str)
        self.assertIsInstance(ColorSync.kCMMApplyTransformProcName, str)
        self.assertIsInstance(ColorSync.kCMMCreateTransformPropertyProcName, str)
